==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/de.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Verwalten Lightbox Gallary Parameter");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "verwalten Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breite");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Bildhöhe");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniaturbildbreite");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniaturbildhöhe");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Titel anzeigen");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktivieren Sie sortieren");
define('MANAGE_GALLERY_DELETE_IMAGE', "Bild löschen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sortierung speichern");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klicken Sie auf &quot;Update&quot; zu veröffentlichen <br /> Ihre hochgeladenen Bilder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle Bilder wurden angepasst und Einstellungen gespeichert wurden.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Es gab einen Fehler die Bilder Ändern der Größe oder Einstellungen zu speichern.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ihr Bild (er) wurde hochgeladen.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Es ist ein Fehler aufgetreten Bild hochladen (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Die Datei, die Sie hochladen möchten, ist kein Bild.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Die Datei, die Sie hochladen möchten, ist zu groß.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Der Titel wurde gespeichert.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sind Sie sicher, dass Sie Bild löschen möchten");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Das Bild wurde gelöscht.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Es war ein Fehler, das Bild zu löschen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Speichern von Parametern und Größe der Bilder, bitte warten ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Hochladen, bitte warten ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Die Sortierreihenfolge nicht gespeichert wurde. Wollen Sie die Sortierreihenfolge zu retten?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Die Bildsortierreihenfolge wurde gespeichert.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Es war ein Fehler, das Bild Art zu speichern.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/de.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Verwalten Lightbox Gallary Parameter");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "verwalten Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breite");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Bildhöhe");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniaturbildbreite");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniaturbildhöhe");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Titel anzeigen");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktivieren Sie sortieren");
define('MANAGE_GALLERY_DELETE_IMAGE', "Bild löschen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sortierung speichern");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klicken Sie auf &quot;Update&quot; zu veröffentlichen <br /> Ihre hochgeladenen Bilder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle Bilder wurden angepasst und Einstellungen gespeichert wurden.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Es gab einen Fehler die Bilder Ändern der Größe oder Einstellungen zu speichern.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ihr Bild (er) wurde hochgeladen.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Es ist ein Fehler aufgetreten Bild hochladen (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Die Datei, die Sie hochladen möchten, ist kein Bild.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Die Datei, die Sie hochladen möchten, ist zu groß.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Der Titel wurde gespeichert.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sind Sie sicher, dass Sie Bild löschen möchten");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Das Bild wurde gelöscht.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Es war ein Fehler, das Bild zu löschen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Speichern von Parametern und Größe der Bilder, bitte warten ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Hochladen, bitte warten ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Die Sortierreihenfolge nicht gespeichert wurde. Wollen Sie die Sortierreihenfolge zu retten?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Die Bildsortierreihenfolge wurde gespeichert.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Es war ein Fehler, das Bild Art zu speichern.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Die Datei, die Sie hochladen möchten, ist größer als die PHP-Einstellungen &#39;upload_max_filesize&#39; oder &#39;post_max_size&#39;. Wenden Sie sich an Ihren Systemadministrator, um diese Grenzwerte zu erhöhen.");
?>
